<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX 歡迎你</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>&amp;Copy for forum</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="47"/>
        <source>Save the displayed system information to a text file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Save text...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Save...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Journald</source>
        <extracomment>systemd journalctl tab</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Log Type</source>
        <extracomment>type of log, either user level or system</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>System</source>
        <extracomment>system level log</extracomment>
        <translation>系統</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>User</source>
        <extracomment>user level log</extracomment>
        <translation>一般用戶</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Priority Level</source>
        <extracomment>level of status message to view</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Choose Boot Log</source>
        <extracomment>choose a boot to view the log</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Service Search</source>
        <extracomment>seek and ye shall find</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Quick System Info</source>
        <translation>快速顯示系統資訊</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Copyright (c) MX Linux</source>
        <translation>MX Linux 版權所有 (c)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>About Quick-System-Info-gui</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>&amp;Find...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Find &amp;Next</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Select &amp;All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Revert Selection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Program for displaying a quick system info report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">授權條款</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>%1 License</source>
        <translation>%1 許可</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Open folder</source>
        <translation>打開文件夾</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>&amp;Save (×%1)...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Find</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;Find what:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Match c&amp;ase</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Match &amp;whole word only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Direction</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="710"/>
        <source>No journal entries found at this admin and priority level</source>
        <comment>no journal entries found at the options specified</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Error running journalctl command</source>
        <comment>error report for journalctl command</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">變更紀錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">關閉（&amp;C）</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Save System Information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>System information saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Could not save system information.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>%1 Help</source>
        <translation>%1 幫助</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="82"/>
        <source>Copy for forum</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>Plain text copy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>本程式必須以一般使用者的身份來執行。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>變更紀錄</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>關閉（&amp;C）</translation>
    </message>
</context>
</TS>